Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/django_resume/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/django_resume/admin.py | 26 | 0 | 0 | 4 | 0 | 100%
src/django_resume/apps.py | 17 | 0 | 0 | 2 | 0 | 100%
src/django_resume/models.py | 15 | 0 | 0 | 2 | 0 | 100%
src/django_resume/plugins/__init__.py | 10 | 0 | 0 | 0 | 0 | 100%
src/django_resume/plugins/about.py | 9 | 0 | 0 | 0 | 0 | 100%
src/django_resume/plugins/base.py | 510 | 14 | 6 | 104 | 14 | 95%
src/django_resume/plugins/education.py | 12 | 0 | 0 | 0 | 0 | 100%
src/django_resume/plugins/identity.py | 75 | 30 | 0 | 12 | 1 | 55%
src/django_resume/plugins/projects.py | 68 | 33 | 0 | 24 | 0 | 47%
src/django_resume/plugins/registry.py | 16 | 0 | 2 | 0 | 0 | 100%
src/django_resume/plugins/skills.py | 16 | 4 | 0 | 2 | 0 | 67%
src/django_resume/plugins/timelines.py | 73 | 7 | 0 | 22 | 2 | 88%
src/django_resume/plugins/tokens.py | 80 | 39 | 0 | 22 | 0 | 46%
src/django_resume/urls.py | 4 | 0 | 0 | 0 | 0 | 100%
src/django_resume/views.py | 14 | 1 | 0 | 2 | 0 | 94%
Total | 945 | 128 | 8 | 196 | 17 | 83%

No items found using the specified filter.